==> openshift-model-tuned-5.12.1-sources.jar: io/fabric8/openshift/api/model/tuned/v1/TunedListBuilder.java <==
package io.fabric8.openshift.api.model.tuned.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class TunedListBuilder extends io.fabric8.openshift.api.model.tuned.v1.TunedListFluentImpl<io.fabric8.openshift.api.model.tuned.v1.TunedListBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.tuned.v1.TunedList,io.fabric8.openshift.api.model.tuned.v1.TunedListBuilder>{
  public TunedListBuilder() {
    this(false);
  }
  public TunedListBuilder(java.lang.Boolean validationEnabled) {
    this(new TunedList(), validationEnabled);
  }
  public TunedListBuilder(io.fabric8.openshift.api.model.tuned.v1.TunedListFluent<?> fluent) {
    this(fluent, false);
  }
  public TunedListBuilder(io.fabric8.openshift.api.model.tuned.v1.TunedListFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new TunedList(), validationEnabled);
  }
  public TunedListBuilder(io.fabric8.openshift.api.model.tuned.v1.TunedListFluent<?> fluent,io.fabric8.openshift.api.model.tuned.v1.TunedList instance) {
    this(fluent, instance, false);
  }
  public TunedListBuilder(io.fabric8.openshift.api.model.tuned.v1.TunedListFluent<?> fluent,io.fabric8.openshift.api.model.tuned.v1.TunedList instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withItems(instance.getItems()); 
    fluent.withKind(instance.getKind()); 
    fluent.withMetadata(instance.getMetadata()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public TunedListBuilder(io.fabric8.openshift.api.model.tuned.v1.TunedList instance) {
    this(instance,false);
  }
  public TunedListBuilder(io.fabric8.openshift.api.model.tuned.v1.TunedList instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withItems(instance.getItems()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.tuned.v1.TunedListFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.tuned.v1.TunedList build() {
    TunedList buildable = new TunedList(fluent.getApiVersion(),fluent.getItems(),fluent.getKind(),fluent.getMetadata());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    TunedListBuilder that = (TunedListBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-tuned-6.5.1-sources.jar: io/fabric8/openshift/api/model/tuned/v1/TunedListBuilder.java <==
package io.fabric8.openshift.api.model.tuned.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class TunedListBuilder extends TunedListFluentImpl<TunedListBuilder> implements VisitableBuilder<TunedList,TunedListBuilder>{
  public TunedListBuilder() {
    this(false);
  }
  public TunedListBuilder(Boolean validationEnabled) {
    this(new TunedList(), validationEnabled);
  }
  public TunedListBuilder(TunedListFluent<?> fluent) {
    this(fluent, false);
  }
  public TunedListBuilder(TunedListFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new TunedList(), validationEnabled);
  }
  public TunedListBuilder(TunedListFluent<?> fluent,TunedList instance) {
    this(fluent, instance, false);
  }
  public TunedListBuilder(TunedListFluent<?> fluent,TunedList instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withItems(instance.getItems()); 
    fluent.withKind(instance.getKind()); 
    fluent.withMetadata(instance.getMetadata()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public TunedListBuilder(TunedList instance) {
    this(instance,false);
  }
  public TunedListBuilder(TunedList instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withItems(instance.getItems()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  TunedListFluent<?> fluent;
  Boolean validationEnabled;
  public TunedList build() {
    TunedList buildable = new TunedList(fluent.getApiVersion(),fluent.getItems(),fluent.getKind(),fluent.getMetadata());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
